# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/decompressor/v3/decompressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/decompressor/v3/decompressor.proto',
  package='envoy.extensions.filters.http.decompressor.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\021DecompressorProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/http/decompressor/v3/decompressor.proto\x12-envoy.extensions.filters.http.decompressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xee\x05\n\x0c\x44\x65\x63ompressor\x12R\n\x14\x64\x65\x63ompressor_library\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12t\n\x18request_direction_config\x18\x02 \x01(\x0b\x32R.envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig\x12v\n\x19response_direction_config\x18\x03 \x01(\x0b\x32S.envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig\x1aR\n\x15\x43ommonDirectionConfig\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x1a\xc1\x01\n\x16RequestDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig\x12=\n\x19\x61\x64vertise_accept_encoding\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x83\x01\n\x17ResponseDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfigBZ\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\x11\x44\x65\x63ompressorProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DECOMPRESSOR_COMMONDIRECTIONCONFIG = _descriptor.Descriptor(
  name='CommonDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=695,
)

_DECOMPRESSOR_REQUESTDIRECTIONCONFIG = _descriptor.Descriptor(
  name='RequestDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_accept_encoding', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig.advertise_accept_encoding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=891,
)

_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG = _descriptor.Descriptor(
  name='ResponseDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1025,
)

_DECOMPRESSOR = _descriptor.Descriptor(
  name='Decompressor',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decompressor_library', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.decompressor_library', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_direction_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.request_direction_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_direction_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.response_direction_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DECOMPRESSOR_COMMONDIRECTIONCONFIG, _DECOMPRESSOR_REQUESTDIRECTIONCONFIG, _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=1025,
)

_DECOMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFEATUREFLAG
_DECOMPRESSOR_COMMONDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _DECOMPRESSOR_COMMONDIRECTIONCONFIG
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['advertise_accept_encoding'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _DECOMPRESSOR_COMMONDIRECTIONCONFIG
_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR.fields_by_name['decompressor_library'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_DECOMPRESSOR.fields_by_name['request_direction_config'].message_type = _DECOMPRESSOR_REQUESTDIRECTIONCONFIG
_DECOMPRESSOR.fields_by_name['response_direction_config'].message_type = _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG
DESCRIPTOR.message_types_by_name['Decompressor'] = _DECOMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Decompressor = _reflection.GeneratedProtocolMessageType('Decompressor', (_message.Message,), {

  'CommonDirectionConfig' : _reflection.GeneratedProtocolMessageType('CommonDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_COMMONDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig)
    })
  ,

  'RequestDirectionConfig' : _reflection.GeneratedProtocolMessageType('RequestDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_REQUESTDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig)
    })
  ,

  'ResponseDirectionConfig' : _reflection.GeneratedProtocolMessageType('ResponseDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig)
    })
  ,
  'DESCRIPTOR' : _DECOMPRESSOR,
  '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor)
  })
_sym_db.RegisterMessage(Decompressor)
_sym_db.RegisterMessage(Decompressor.CommonDirectionConfig)
_sym_db.RegisterMessage(Decompressor.RequestDirectionConfig)
_sym_db.RegisterMessage(Decompressor.ResponseDirectionConfig)


DESCRIPTOR._options = None
_DECOMPRESSOR.fields_by_name['decompressor_library']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/collection_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from xds.core.v3 import resource_locator_pb2 as xds_dot_core_dot_v3_dot_resource__locator__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xds/core/v3/collection_entry.proto',
  package='xds.core.v3',
  syntax='proto3',
  serialized_options=b'\n\033com.github.udpa.xds.core.v3B\024CollectionEntryProtoP\001\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"xds/core/v3/collection_entry.proto\x12\x0bxds.core.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a\"xds/core/v3/resource_locator.proto\x1a\x17validate/validate.proto\"\x93\x02\n\x0f\x43ollectionEntry\x12/\n\x07locator\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.ResourceLocatorH\x00\x12@\n\x0cinline_entry\x18\x02 \x01(\x0b\x32(.xds.core.v3.CollectionEntry.InlineEntryH\x00\x1ar\n\x0bInlineEntry\x12*\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x15^[0-9a-zA-Z_\\-\\.~:]+$\x12\x0f\n\x07version\x18\x02 \x01(\t\x12&\n\x08resource\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\n\x12resource_specifier\x12\x03\xf8\x42\x01\x42=\n\x1b\x63om.github.udpa.xds.core.v3B\x14\x43ollectionEntryProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_resource__locator__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_COLLECTIONENTRY_INLINEENTRY = _descriptor.Descriptor(
  name='InlineEntry',
  full_name='xds.core.v3.CollectionEntry.InlineEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xds.core.v3.CollectionEntry.InlineEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\031r\0272\025^[0-9a-zA-Z_\\-\\.~:]+$', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='xds.core.v3.CollectionEntry.InlineEntry.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='xds.core.v3.CollectionEntry.InlineEntry.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=419,
)

_COLLECTIONENTRY = _descriptor.Descriptor(
  name='CollectionEntry',
  full_name='xds.core.v3.CollectionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locator', full_name='xds.core.v3.CollectionEntry.locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inline_entry', full_name='xds.core.v3.CollectionEntry.inline_entry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COLLECTIONENTRY_INLINEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resource_specifier', full_name='xds.core.v3.CollectionEntry.resource_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=171,
  serialized_end=446,
)

_COLLECTIONENTRY_INLINEENTRY.fields_by_name['resource'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_COLLECTIONENTRY_INLINEENTRY.containing_type = _COLLECTIONENTRY
_COLLECTIONENTRY.fields_by_name['locator'].message_type = xds_dot_core_dot_v3_dot_resource__locator__pb2._RESOURCELOCATOR
_COLLECTIONENTRY.fields_by_name['inline_entry'].message_type = _COLLECTIONENTRY_INLINEENTRY
_COLLECTIONENTRY.oneofs_by_name['resource_specifier'].fields.append(
  _COLLECTIONENTRY.fields_by_name['locator'])
_COLLECTIONENTRY.fields_by_name['locator'].containing_oneof = _COLLECTIONENTRY.oneofs_by_name['resource_specifier']
_COLLECTIONENTRY.oneofs_by_name['resource_specifier'].fields.append(
  _COLLECTIONENTRY.fields_by_name['inline_entry'])
_COLLECTIONENTRY.fields_by_name['inline_entry'].containing_oneof = _COLLECTIONENTRY.oneofs_by_name['resource_specifier']
DESCRIPTOR.message_types_by_name['CollectionEntry'] = _COLLECTIONENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CollectionEntry = _reflection.GeneratedProtocolMessageType('CollectionEntry', (_message.Message,), {

  'InlineEntry' : _reflection.GeneratedProtocolMessageType('InlineEntry', (_message.Message,), {
    'DESCRIPTOR' : _COLLECTIONENTRY_INLINEENTRY,
    '__module__' : 'xds.core.v3.collection_entry_pb2'
    # @@protoc_insertion_point(class_scope:xds.core.v3.CollectionEntry.InlineEntry)
    })
  ,
  'DESCRIPTOR' : _COLLECTIONENTRY,
  '__module__' : 'xds.core.v3.collection_entry_pb2'
  # @@protoc_insertion_point(class_scope:xds.core.v3.CollectionEntry)
  })
_sym_db.RegisterMessage(CollectionEntry)
_sym_db.RegisterMessage(CollectionEntry.InlineEntry)


DESCRIPTOR._options = None
_COLLECTIONENTRY_INLINEENTRY.fields_by_name['name']._options = None
_COLLECTIONENTRY.oneofs_by_name['resource_specifier']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v4alpha/path.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v4alpha/path.proto',
  package='envoy.type.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.type.matcher.v4alphaB\tPathProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/type/matcher/v4alpha/path.proto\x12\x1a\x65nvoy.type.matcher.v4alpha\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x89\x01\n\x0bPathMatcher\x12\x43\n\x04path\x18\x01 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:(\x9a\xc5\x88\x1e#\n!envoy.type.matcher.v3.PathMatcherB\x0b\n\x04rule\x12\x03\xf8\x42\x01\x42?\n(io.envoyproxy.envoy.type.matcher.v4alphaB\tPathProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PATHMATCHER = _descriptor.Descriptor(
  name='PathMatcher',
  full_name='envoy.type.matcher.v4alpha.PathMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.type.matcher.v4alpha.PathMatcher.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.type.matcher.v3.PathMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.type.matcher.v4alpha.PathMatcher.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=202,
  serialized_end=339,
)

_PATHMATCHER.fields_by_name['path'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_PATHMATCHER.oneofs_by_name['rule'].fields.append(
  _PATHMATCHER.fields_by_name['path'])
_PATHMATCHER.fields_by_name['path'].containing_oneof = _PATHMATCHER.oneofs_by_name['rule']
DESCRIPTOR.message_types_by_name['PathMatcher'] = _PATHMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PathMatcher = _reflection.GeneratedProtocolMessageType('PathMatcher', (_message.Message,), {
  'DESCRIPTOR' : _PATHMATCHER,
  '__module__' : 'envoy.type.matcher.v4alpha.path_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.PathMatcher)
  })
_sym_db.RegisterMessage(PathMatcher)


DESCRIPTOR._options = None
_PATHMATCHER.oneofs_by_name['rule']._options = None
_PATHMATCHER.fields_by_name['path']._options = None
_PATHMATCHER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/ext_authz/v2/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/ext_authz/v2/ext_authz.proto',
  package='envoy.config.filter.network.ext_authz.v2',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.config.filter.network.ext_authz.v2B\rExtAuthzProtoP\001\362\230\376\217\005/\022-envoy.extensions.filters.network.ext_authz.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/config/filter/network/ext_authz/v2/ext_authz.proto\x12(envoy.config.filter.network.ext_authz.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9c\x01\n\x08\x45xtAuthz\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x03 \x01(\x08\x12 \n\x18include_peer_certificate\x18\x04 \x01(\x08\x42\x86\x01\n6io.envoyproxy.envoy.config.filter.network.ext_authz.v2B\rExtAuthzProtoP\x01\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.network.ext_authz.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.config.filter.network.ext_authz.v2.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.ext_authz.v2.ExtAuthz.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.filter.network.ext_authz.v2.ExtAuthz.grpc_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.config.filter.network.ext_authz.v2.ExtAuthz.failure_mode_allow', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.config.filter.network.ext_authz.v2.ExtAuthz.include_peer_certificate', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=385,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.config.filter.network.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.ext_authz.v2.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['stat_prefix']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto',
  package='envoy.extensions.filters.network.mysql_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.network.mysql_proxy.v3B\017MysqlProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto\x12/envoy.extensions.filters.network.mysql_proxy.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x01\n\nMySQLProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\naccess_log\x18\x02 \x01(\t:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.network.mysql_proxy.v1alpha1.MySQLProxyBZ\n=io.envoyproxy.envoy.extensions.filters.network.mysql_proxy.v3B\x0fMysqlProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MYSQLPROXY = _descriptor.Descriptor(
  name='MySQLProxy',
  full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy.access_log', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.filter.network.mysql_proxy.v1alpha1.MySQLProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=340,
)

DESCRIPTOR.message_types_by_name['MySQLProxy'] = _MYSQLPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MySQLProxy = _reflection.GeneratedProtocolMessageType('MySQLProxy', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLPROXY,
  '__module__' : 'envoy.extensions.filters.network.mysql_proxy.v3.mysql_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy)
  })
_sym_db.RegisterMessage(MySQLProxy)


DESCRIPTOR._options = None
_MYSQLPROXY.fields_by_name['stat_prefix']._options = None
_MYSQLPROXY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/redis_proxy/v3/redis_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/redis_proxy/v3/redis_proxy.proto',
  package='envoy.extensions.filters.network.redis_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.network.redis_proxy.v3B\017RedisProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/extensions/filters/network/redis_proxy/v3/redis_proxy.proto\x12/envoy.extensions.filters.network.redis_proxy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9a\x13\n\nRedisProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12h\n\x08settings\x18\x03 \x01(\x0b\x32L.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11latency_in_micros\x18\x04 \x01(\x08\x12_\n\rprefix_routes\x18\x05 \x01(\x0b\x32H.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes\x12J\n\x18\x64ownstream_auth_password\x18\x06 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12V\n\x06\x66\x61ults\x18\x08 \x03(\x0b\x32\x46.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault\x12J\n\x18\x64ownstream_auth_username\x18\x07 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x1a\x8f\x05\n\x10\x43onnPoolSettings\x12\x37\n\nop_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x08\x01\x12\x1a\n\x12\x65nable_hashtagging\x18\x02 \x01(\x08\x12\x1a\n\x12\x65nable_redirection\x18\x03 \x01(\x08\x12$\n\x1cmax_buffer_size_before_flush\x18\x04 \x01(\r\x12\x37\n\x14\x62uffer_flush_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n max_upstream_unknown_connections\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14\x65nable_command_stats\x18\x08 \x01(\x08\x12v\n\x0bread_policy\x18\x07 \x01(\x0e\x32W.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.ReadPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"~\n\nReadPolicy\x12\x1b\n\x06MASTER\x10\x00\x1a\x0f\xf2\x98\xfe\x8f\x05\t\n\x07PRIMARY\x12)\n\rPREFER_MASTER\x10\x01\x1a\x16\xf2\x98\xfe\x8f\x05\x10\n\x0ePREFER_PRIMARY\x12\x0b\n\x07REPLICA\x10\x02\x12\x12\n\x0ePREFER_REPLICA\x10\x03\x12\x07\n\x03\x41NY\x10\x04:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings\x1a\xff\x06\n\x0cPrefixRoutes\x12^\n\x06routes\x18\x01 \x03(\x0b\x32N.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route\x12\x18\n\x10\x63\x61se_insensitive\x18\x02 \x01(\x08\x12g\n\x0f\x63\x61tch_all_route\x18\x04 \x01(\x0b\x32N.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route\x1a\xa7\x04\n\x05Route\x12\x18\n\x06prefix\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03(\xe8\x07\x12\x15\n\rremove_prefix\x18\x02 \x01(\x08\x12\x18\n\x07\x63luster\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x81\x01\n\x15request_mirror_policy\x18\x04 \x03(\x0b\x32\x62.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy\x1a\xfd\x01\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12H\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12\x1d\n\x15\x65xclude_read_commands\x18\x03 \x01(\x08:c\x9a\xc5\x88\x1e^\n\\envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy:O\x9a\xc5\x88\x1eJ\nHenvoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route:I\x9a\xc5\x88\x1e\x44\nBenvoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutesJ\x04\x08\x03\x10\x04R\x11\x63\x61tch_all_cluster\x1a\xb6\x02\n\nRedisFault\x12s\n\nfault_type\x18\x01 \x01(\x0e\x32U.envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.RedisFaultTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12O\n\rfault_enabled\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08\x63ommands\x18\x04 \x03(\t\"&\n\x0eRedisFaultType\x12\t\n\x05\x44\x45LAY\x10\x00\x12\t\n\x05\x45RROR\x10\x01:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.network.redis_proxy.v2.RedisProxyJ\x04\x08\x02\x10\x03R\x07\x63luster\"\xe0\x01\n\x14RedisProtocolOptions\x12?\n\rauth_password\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12?\n\rauth_username\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01:F\x9a\xc5\x88\x1e\x41\n?envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptionsBZ\n=io.envoyproxy.envoy.extensions.filters.network.redis_proxy.v3B\x0fRedisProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_REDISPROXY_CONNPOOLSETTINGS_READPOLICY = _descriptor.EnumDescriptor(
  name='ReadPolicy',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.ReadPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MASTER', index=0, number=0,
      serialized_options=b'\362\230\376\217\005\t\n\007PRIMARY',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_MASTER', index=1, number=1,
      serialized_options=b'\362\230\376\217\005\020\n\016PREFER_PRIMARY',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLICA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_REPLICA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1338,
  serialized_end=1464,
)
_sym_db.RegisterEnumDescriptor(_REDISPROXY_CONNPOOLSETTINGS_READPOLICY)

_REDISPROXY_REDISFAULT_REDISFAULTTYPE = _descriptor.EnumDescriptor(
  name='RedisFaultType',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.RedisFaultType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DELAY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2716,
  serialized_end=2754,
)
_sym_db.RegisterEnumDescriptor(_REDISPROXY_REDISFAULT_REDISFAULTTYPE)


_REDISPROXY_CONNPOOLSETTINGS = _descriptor.Descriptor(
  name='ConnPoolSettings',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_timeout', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.op_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hashtagging', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.enable_hashtagging', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_redirection', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.enable_redirection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_buffer_size_before_flush', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.max_buffer_size_before_flush', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_timeout', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.buffer_flush_timeout', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_upstream_unknown_connections', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.max_upstream_unknown_connections', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_command_stats', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.enable_command_stats', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_policy', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings.read_policy', index=7,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDISPROXY_CONNPOOLSETTINGS_READPOLICY,
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=1543,
)

_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY = _descriptor.Descriptor(
  name='RequestMirrorPolicy',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_fraction', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.runtime_fraction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_read_commands', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.exclude_read_commands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036^\n\\envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2007,
  serialized_end=2260,
)

_REDISPROXY_PREFIXROUTES_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003(\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_prefix', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.remove_prefix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_mirror_policy', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.request_mirror_policy', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036J\nHenvoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=2341,
)

_REDISPROXY_PREFIXROUTES = _descriptor.Descriptor(
  name='PrefixRoutes',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.case_insensitive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catch_all_route', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.catch_all_route', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036D\nBenvoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=2441,
)

_REDISPROXY_REDISFAULT = _descriptor.Descriptor(
  name='RedisFault',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fault_type', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.fault_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fault_enabled', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.fault_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault.commands', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDISPROXY_REDISFAULT_REDISFAULTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2444,
  serialized_end=2754,
)

_REDISPROXY = _descriptor.Descriptor(
  name='RedisProxy',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.settings', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_in_micros', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.latency_in_micros', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_routes', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.prefix_routes', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_auth_password', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.downstream_auth_password', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='faults', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.faults', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_auth_username', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.downstream_auth_username', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_CONNPOOLSETTINGS, _REDISPROXY_PREFIXROUTES, _REDISPROXY_REDISFAULT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.config.filter.network.redis_proxy.v2.RedisProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=2831,
)


_REDISPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='RedisProtocolOptions',
  full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_password', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProtocolOptions.auth_password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_username', full_name='envoy.extensions.filters.network.redis_proxy.v3.RedisProtocolOptions.auth_username', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2834,
  serialized_end=3058,
)

_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['buffer_flush_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['max_upstream_unknown_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy'].enum_type = _REDISPROXY_CONNPOOLSETTINGS_READPOLICY
_REDISPROXY_CONNPOOLSETTINGS.containing_type = _REDISPROXY
_REDISPROXY_CONNPOOLSETTINGS_READPOLICY.containing_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['runtime_fraction'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.containing_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['request_mirror_policy'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY
_REDISPROXY_PREFIXROUTES_ROUTE.containing_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY_PREFIXROUTES.fields_by_name['routes'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_route'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.containing_type = _REDISPROXY
_REDISPROXY_REDISFAULT.fields_by_name['fault_type'].enum_type = _REDISPROXY_REDISFAULT_REDISFAULTTYPE
_REDISPROXY_REDISFAULT.fields_by_name['fault_enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_REDISPROXY_REDISFAULT.fields_by_name['delay'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_REDISFAULT.containing_type = _REDISPROXY
_REDISPROXY_REDISFAULT_REDISFAULTTYPE.containing_type = _REDISPROXY_REDISFAULT
_REDISPROXY.fields_by_name['settings'].message_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY.fields_by_name['prefix_routes'].message_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY.fields_by_name['downstream_auth_password'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_REDISPROXY.fields_by_name['faults'].message_type = _REDISPROXY_REDISFAULT
_REDISPROXY.fields_by_name['downstream_auth_username'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_REDISPROTOCOLOPTIONS.fields_by_name['auth_username'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
DESCRIPTOR.message_types_by_name['RedisProxy'] = _REDISPROXY
DESCRIPTOR.message_types_by_name['RedisProtocolOptions'] = _REDISPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisProxy = _reflection.GeneratedProtocolMessageType('RedisProxy', (_message.Message,), {

  'ConnPoolSettings' : _reflection.GeneratedProtocolMessageType('ConnPoolSettings', (_message.Message,), {
    'DESCRIPTOR' : _REDISPROXY_CONNPOOLSETTINGS,
    '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.ConnPoolSettings)
    })
  ,

  'PrefixRoutes' : _reflection.GeneratedProtocolMessageType('PrefixRoutes', (_message.Message,), {

    'Route' : _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {

      'RequestMirrorPolicy' : _reflection.GeneratedProtocolMessageType('RequestMirrorPolicy', (_message.Message,), {
        'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY,
        '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
        # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)
        })
      ,
      'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE,
      '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
      # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes.Route)
      })
    ,
    'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES,
    '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.PrefixRoutes)
    })
  ,

  'RedisFault' : _reflection.GeneratedProtocolMessageType('RedisFault', (_message.Message,), {
    'DESCRIPTOR' : _REDISPROXY_REDISFAULT,
    '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy.RedisFault)
    })
  ,
  'DESCRIPTOR' : _REDISPROXY,
  '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProxy)
  })
_sym_db.RegisterMessage(RedisProxy)
_sym_db.RegisterMessage(RedisProxy.ConnPoolSettings)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)
_sym_db.RegisterMessage(RedisProxy.RedisFault)

RedisProtocolOptions = _reflection.GeneratedProtocolMessageType('RedisProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _REDISPROTOCOLOPTIONS,
  '__module__' : 'envoy.extensions.filters.network.redis_proxy.v3.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.redis_proxy.v3.RedisProtocolOptions)
  })
_sym_db.RegisterMessage(RedisProtocolOptions)


DESCRIPTOR._options = None
_REDISPROXY_CONNPOOLSETTINGS_READPOLICY.values_by_name["MASTER"]._options = None
_REDISPROXY_CONNPOOLSETTINGS_READPOLICY.values_by_name["PREFER_MASTER"]._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout']._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy']._options = None
_REDISPROXY_CONNPOOLSETTINGS._options = None
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY._options = None
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['prefix']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE._options = None
_REDISPROXY_PREFIXROUTES._options = None
_REDISPROXY_REDISFAULT.fields_by_name['fault_type']._options = None
_REDISPROXY_REDISFAULT.fields_by_name['fault_enabled']._options = None
_REDISPROXY.fields_by_name['stat_prefix']._options = None
_REDISPROXY.fields_by_name['settings']._options = None
_REDISPROXY.fields_by_name['downstream_auth_password']._options = None
_REDISPROXY.fields_by_name['downstream_auth_username']._options = None
_REDISPROXY._options = None
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password']._options = None
_REDISPROTOCOLOPTIONS.fields_by_name['auth_username']._options = None
_REDISPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/dubbo_proxy/v3/route.proto',
  package='envoy.extensions.filters.network.dubbo_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;envoy/extensions/filters/network/dubbo_proxy/v3/route.proto\x12/envoy.extensions.filters.network.dubbo_proxy.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe9\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tinterface\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x46\n\x06routes\x18\x05 \x03(\x0b\x32\x36.envoy.extensions.filters.network.dubbo_proxy.v3.Route:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration\"\xf3\x01\n\x05Route\x12T\n\x05match\x18\x01 \x01(\x0b\x32;.envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12U\n\x05route\x18\x02 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route\"\xd5\x01\n\nRouteMatch\x12L\n\x06method\x18\x01 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch\"\xc4\x01\n\x0bRouteAction\x12\x11\n\x07\x63luster\x18\x01 \x01(\tH\x00\x12\x43\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32&.envoy.config.route.v3.WeightedClusterH\x00:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xd5\x04\n\x0bMethodMatch\x12\x32\n\x04name\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x63\n\x0cparams_match\x18\x02 \x03(\x0b\x32M.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry\x1a\xdc\x01\n\x17ParameterMatchSpecifier\x12\x15\n\x0b\x65xact_match\x18\x03 \x01(\tH\x00\x12\x30\n\x0brange_match\x18\x04 \x01(\x0b\x32\x19.envoy.type.v3.Int64RangeH\x00:[\x9a\xc5\x88\x1eV\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifierB\x1b\n\x19parameter_match_specifier\x1a\x88\x01\n\x10ParamsMatchEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x63\n\x05value\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatchBU\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTECONFIGURATION = _descriptor.Descriptor(
  name='RouteConfiguration',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration.interface', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration.routes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036E\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=546,
)


_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.Route.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.Route.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=792,
)


_ROUTEMATCH = _descriptor.Descriptor(
  name='RouteMatch',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatch.method', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatch.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=1008,
)


_ROUTEACTION = _descriptor.Descriptor(
  name='RouteAction',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteAction.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_clusters', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteAction.weighted_clusters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_specifier', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.RouteAction.cluster_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1011,
  serialized_end=1207,
)


_METHODMATCH_PARAMETERMATCHSPECIFIER = _descriptor.Descriptor(
  name='ParameterMatchSpecifier',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact_match', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier.exact_match', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_match', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier.range_match', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036V\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifier',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameter_match_specifier', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier.parameter_match_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1379,
  serialized_end=1599,
)

_METHODMATCH_PARAMSMATCHENTRY = _descriptor.Descriptor(
  name='ParamsMatchEntry',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1602,
  serialized_end=1738,
)

_METHODMATCH = _descriptor.Descriptor(
  name='MethodMatch',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params_match', full_name='envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.params_match', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METHODMATCH_PARAMETERMATCHSPECIFIER, _METHODMATCH_PARAMSMATCHENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1807,
)

_ROUTECONFIGURATION.fields_by_name['routes'].message_type = _ROUTE
_ROUTE.fields_by_name['match'].message_type = _ROUTEMATCH
_ROUTE.fields_by_name['route'].message_type = _ROUTEACTION
_ROUTEMATCH.fields_by_name['method'].message_type = _METHODMATCH
_ROUTEMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._HEADERMATCHER
_ROUTEACTION.fields_by_name['weighted_clusters'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._WEIGHTEDCLUSTER
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['cluster'])
_ROUTEACTION.fields_by_name['cluster'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['weighted_clusters'])
_ROUTEACTION.fields_by_name['weighted_clusters'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_METHODMATCH_PARAMETERMATCHSPECIFIER.fields_by_name['range_match'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT64RANGE
_METHODMATCH_PARAMETERMATCHSPECIFIER.containing_type = _METHODMATCH
_METHODMATCH_PARAMETERMATCHSPECIFIER.oneofs_by_name['parameter_match_specifier'].fields.append(
  _METHODMATCH_PARAMETERMATCHSPECIFIER.fields_by_name['exact_match'])
_METHODMATCH_PARAMETERMATCHSPECIFIER.fields_by_name['exact_match'].containing_oneof = _METHODMATCH_PARAMETERMATCHSPECIFIER.oneofs_by_name['parameter_match_specifier']
_METHODMATCH_PARAMETERMATCHSPECIFIER.oneofs_by_name['parameter_match_specifier'].fields.append(
  _METHODMATCH_PARAMETERMATCHSPECIFIER.fields_by_name['range_match'])
_METHODMATCH_PARAMETERMATCHSPECIFIER.fields_by_name['range_match'].containing_oneof = _METHODMATCH_PARAMETERMATCHSPECIFIER.oneofs_by_name['parameter_match_specifier']
_METHODMATCH_PARAMSMATCHENTRY.fields_by_name['value'].message_type = _METHODMATCH_PARAMETERMATCHSPECIFIER
_METHODMATCH_PARAMSMATCHENTRY.containing_type = _METHODMATCH
_METHODMATCH.fields_by_name['name'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_METHODMATCH.fields_by_name['params_match'].message_type = _METHODMATCH_PARAMSMATCHENTRY
DESCRIPTOR.message_types_by_name['RouteConfiguration'] = _ROUTECONFIGURATION
DESCRIPTOR.message_types_by_name['Route'] = _ROUTE
DESCRIPTOR.message_types_by_name['RouteMatch'] = _ROUTEMATCH
DESCRIPTOR.message_types_by_name['RouteAction'] = _ROUTEACTION
DESCRIPTOR.message_types_by_name['MethodMatch'] = _METHODMATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RouteConfiguration = _reflection.GeneratedProtocolMessageType('RouteConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROUTECONFIGURATION,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfiguration)
  })
_sym_db.RegisterMessage(RouteConfiguration)

Route = _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {
  'DESCRIPTOR' : _ROUTE,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.Route)
  })
_sym_db.RegisterMessage(Route)

RouteMatch = _reflection.GeneratedProtocolMessageType('RouteMatch', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEMATCH,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatch)
  })
_sym_db.RegisterMessage(RouteMatch)

RouteAction = _reflection.GeneratedProtocolMessageType('RouteAction', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEACTION,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.RouteAction)
  })
_sym_db.RegisterMessage(RouteAction)

MethodMatch = _reflection.GeneratedProtocolMessageType('MethodMatch', (_message.Message,), {

  'ParameterMatchSpecifier' : _reflection.GeneratedProtocolMessageType('ParameterMatchSpecifier', (_message.Message,), {
    'DESCRIPTOR' : _METHODMATCH_PARAMETERMATCHSPECIFIER,
    '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier)
    })
  ,

  'ParamsMatchEntry' : _reflection.GeneratedProtocolMessageType('ParamsMatchEntry', (_message.Message,), {
    'DESCRIPTOR' : _METHODMATCH_PARAMSMATCHENTRY,
    '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry)
    })
  ,
  'DESCRIPTOR' : _METHODMATCH,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch)
  })
_sym_db.RegisterMessage(MethodMatch)
_sym_db.RegisterMessage(MethodMatch.ParameterMatchSpecifier)
_sym_db.RegisterMessage(MethodMatch.ParamsMatchEntry)


DESCRIPTOR._options = None
_ROUTECONFIGURATION._options = None
_ROUTE.fields_by_name['match']._options = None
_ROUTE.fields_by_name['route']._options = None
_ROUTE._options = None
_ROUTEMATCH._options = None
_ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
_ROUTEACTION._options = None
_METHODMATCH_PARAMETERMATCHSPECIFIER._options = None
_METHODMATCH_PARAMSMATCHENTRY._options = None
_METHODMATCH._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/tcp_proxy/v4alpha/tcp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v4alpha import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.type.v3 import hash_policy_pb2 as envoy_dot_type_dot_v3_dot_hash__policy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/tcp_proxy/v4alpha/tcp_proxy.proto',
  package='envoy.extensions.filters.network.tcp_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\n@io.envoyproxy.envoy.extensions.filters.network.tcp_proxy.v4alphaB\rTcpProxyProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nBenvoy/extensions/filters/network/tcp_proxy/v4alpha/tcp_proxy.proto\x12\x32\x65nvoy.extensions.filters.network.tcp_proxy.v4alpha\x1a.envoy/config/accesslog/v4alpha/accesslog.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1f\x65nvoy/type/v3/hash_policy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8b\x0c\n\x08TcpProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\x07\x63luster\x18\x02 \x01(\tH\x00\x12i\n\x11weighted_clusters\x18\n \x01(\x0b\x32L.envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedClusterH\x00\x12;\n\x0emetadata_match\x18\t \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12/\n\x0cidle_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17\x64ownstream_idle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15upstream_idle_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\naccess_log\x18\x05 \x03(\x0b\x32).envoy.config.accesslog.v4alpha.AccessLog\x12\x43\n\x14max_connect_attempts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x38\n\x0bhash_policy\x18\x0b \x03(\x0b\x32\x19.envoy.type.v3.HashPolicyB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x12\x66\n\x10tunneling_config\x18\x0c \x01(\x0b\x32L.envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig\x12S\n\"max_downstream_connection_duration\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x1a\xb4\x03\n\x0fWeightedCluster\x12v\n\x08\x63lusters\x18\x01 \x03(\x0b\x32Z.envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xd9\x01\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06weight\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x01\x12;\n\x0emetadata_match\x18\x03 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata:[\x9a\xc5\x88\x1eV\nTenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.WeightedCluster.ClusterWeight:M\x9a\xc5\x88\x1eH\nFenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.WeightedCluster\x1a\xde\x01\n\x0fTunnelingConfig\x12\x19\n\x08hostname\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08use_post\x18\x02 \x01(\x08\x12O\n\x0eheaders_to_add\x18\x03 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07:M\x9a\xc5\x88\x1eH\nFenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.TunnelingConfig:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.network.tcp_proxy.v3.TcpProxyB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01J\x04\x08\x06\x10\x07R\rdeprecated_v1B[\n@io.envoyproxy.envoy.extensions.filters.network.tcp_proxy.v4alphaB\rTcpProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_hash__policy__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT = _descriptor.Descriptor(
  name='ClusterWeight',
  full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeight.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeight.weight', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeight.metadata_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036V\nTenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.WeightedCluster.ClusterWeight',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1313,
  serialized_end=1530,
)

_TCPPROXY_WEIGHTEDCLUSTER = _descriptor.Descriptor(
  name='WeightedCluster',
  full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.WeightedCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1609,
)

_TCPPROXY_TUNNELINGCONFIG = _descriptor.Descriptor(
  name='TunnelingConfig',
  full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_post', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig.use_post', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig.headers_to_add', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.extensions.filters.network.tcp_proxy.v3.TcpProxy.TunnelingConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1834,
)

_TCPPROXY = _descriptor.Descriptor(
  name='TcpProxy',
  full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_clusters', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.weighted_clusters', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.metadata_match', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.idle_timeout', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_idle_timeout', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.downstream_idle_timeout', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_idle_timeout', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.upstream_idle_timeout', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.access_log', index=7,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connect_attempts', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.max_connect_attempts', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_policy', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.hash_policy', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunneling_config', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.tunneling_config', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_downstream_connection_duration', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.max_downstream_connection_duration', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\252\001\0062\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TCPPROXY_WEIGHTEDCLUSTER, _TCPPROXY_TUNNELINGCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.network.tcp_proxy.v3.TcpProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_specifier', full_name='envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.cluster_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=397,
  serialized_end=1944,
)

_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.containing_type = _TCPPROXY_WEIGHTEDCLUSTER
_TCPPROXY_WEIGHTEDCLUSTER.fields_by_name['clusters'].message_type = _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT
_TCPPROXY_WEIGHTEDCLUSTER.containing_type = _TCPPROXY
_TCPPROXY_TUNNELINGCONFIG.fields_by_name['headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_TCPPROXY_TUNNELINGCONFIG.containing_type = _TCPPROXY
_TCPPROXY.fields_by_name['weighted_clusters'].message_type = _TCPPROXY_WEIGHTEDCLUSTER
_TCPPROXY.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_TCPPROXY.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TCPPROXY.fields_by_name['downstream_idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TCPPROXY.fields_by_name['upstream_idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TCPPROXY.fields_by_name['access_log'].message_type = envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2._ACCESSLOG
_TCPPROXY.fields_by_name['max_connect_attempts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TCPPROXY.fields_by_name['hash_policy'].message_type = envoy_dot_type_dot_v3_dot_hash__policy__pb2._HASHPOLICY
_TCPPROXY.fields_by_name['tunneling_config'].message_type = _TCPPROXY_TUNNELINGCONFIG
_TCPPROXY.fields_by_name['max_downstream_connection_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TCPPROXY.oneofs_by_name['cluster_specifier'].fields.append(
  _TCPPROXY.fields_by_name['cluster'])
_TCPPROXY.fields_by_name['cluster'].containing_oneof = _TCPPROXY.oneofs_by_name['cluster_specifier']
_TCPPROXY.oneofs_by_name['cluster_specifier'].fields.append(
  _TCPPROXY.fields_by_name['weighted_clusters'])
_TCPPROXY.fields_by_name['weighted_clusters'].containing_oneof = _TCPPROXY.oneofs_by_name['cluster_specifier']
DESCRIPTOR.message_types_by_name['TcpProxy'] = _TCPPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TcpProxy = _reflection.GeneratedProtocolMessageType('TcpProxy', (_message.Message,), {

  'WeightedCluster' : _reflection.GeneratedProtocolMessageType('WeightedCluster', (_message.Message,), {

    'ClusterWeight' : _reflection.GeneratedProtocolMessageType('ClusterWeight', (_message.Message,), {
      'DESCRIPTOR' : _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT,
      '__module__' : 'envoy.extensions.filters.network.tcp_proxy.v4alpha.tcp_proxy_pb2'
      # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster.ClusterWeight)
      })
    ,
    'DESCRIPTOR' : _TCPPROXY_WEIGHTEDCLUSTER,
    '__module__' : 'envoy.extensions.filters.network.tcp_proxy.v4alpha.tcp_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.WeightedCluster)
    })
  ,

  'TunnelingConfig' : _reflection.GeneratedProtocolMessageType('TunnelingConfig', (_message.Message,), {
    'DESCRIPTOR' : _TCPPROXY_TUNNELINGCONFIG,
    '__module__' : 'envoy.extensions.filters.network.tcp_proxy.v4alpha.tcp_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy.TunnelingConfig)
    })
  ,
  'DESCRIPTOR' : _TCPPROXY,
  '__module__' : 'envoy.extensions.filters.network.tcp_proxy.v4alpha.tcp_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.tcp_proxy.v4alpha.TcpProxy)
  })
_sym_db.RegisterMessage(TcpProxy)
_sym_db.RegisterMessage(TcpProxy.WeightedCluster)
_sym_db.RegisterMessage(TcpProxy.WeightedCluster.ClusterWeight)
_sym_db.RegisterMessage(TcpProxy.TunnelingConfig)


DESCRIPTOR._options = None
_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT._options = None
_TCPPROXY_WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
_TCPPROXY_WEIGHTEDCLUSTER._options = None
_TCPPROXY_TUNNELINGCONFIG.fields_by_name['hostname']._options = None
_TCPPROXY_TUNNELINGCONFIG.fields_by_name['headers_to_add']._options = None
_TCPPROXY_TUNNELINGCONFIG._options = None
_TCPPROXY.oneofs_by_name['cluster_specifier']._options = None
_TCPPROXY.fields_by_name['stat_prefix']._options = None
_TCPPROXY.fields_by_name['max_connect_attempts']._options = None
_TCPPROXY.fields_by_name['hash_policy']._options = None
_TCPPROXY.fields_by_name['max_downstream_connection_duration']._options = None
_TCPPROXY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/http/http/v3/http_connection_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/http/http/v3/http_connection_pool.proto',
  package='envoy.extensions.upstreams.http.http.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.upstreams.http.http.v3B!HttpConnectionPoolProtoOuterClassP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nBenvoy/extensions/upstreams/http/http/v3/http_connection_pool.proto\x12\'envoy.extensions.upstreams.http.http.v3\x1a\x1dudpa/annotations/status.proto\"\x19\n\x17HttpConnectionPoolProtoBd\n5io.envoyproxy.envoy.extensions.upstreams.http.http.v3B!HttpConnectionPoolProtoOuterClassP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_HTTPCONNECTIONPOOLPROTO = _descriptor.Descriptor(
  name='HttpConnectionPoolProto',
  full_name='envoy.extensions.upstreams.http.http.v3.HttpConnectionPoolProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=167,
)

DESCRIPTOR.message_types_by_name['HttpConnectionPoolProto'] = _HTTPCONNECTIONPOOLPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpConnectionPoolProto = _reflection.GeneratedProtocolMessageType('HttpConnectionPoolProto', (_message.Message,), {
  'DESCRIPTOR' : _HTTPCONNECTIONPOOLPROTO,
  '__module__' : 'envoy.extensions.upstreams.http.http.v3.http_connection_pool_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.http.v3.HttpConnectionPoolProto)
  })
_sym_db.RegisterMessage(HttpConnectionPoolProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/number.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v3/number.proto',
  package='envoy.type.matcher.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.type.matcher.v3B\013NumberProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/type/matcher/v3/number.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8c\x01\n\rDoubleMatcher\x12+\n\x05range\x18\x01 \x01(\x0b\x32\x1a.envoy.type.v3.DoubleRangeH\x00\x12\x0f\n\x05\x65xact\x18\x02 \x01(\x01H\x00:\'\x9a\xc5\x88\x1e\"\n envoy.type.matcher.DoubleMatcherB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\x42<\n#io.envoyproxy.envoy.type.matcher.v3B\x0bNumberProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DOUBLEMATCHER = _descriptor.Descriptor(
  name='DoubleMatcher',
  full_name='envoy.type.matcher.v3.DoubleMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='envoy.type.matcher.v3.DoubleMatcher.range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exact', full_name='envoy.type.matcher.v3.DoubleMatcher.exact', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.type.matcher.DoubleMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_pattern', full_name='envoy.type.matcher.v3.DoubleMatcher.match_pattern',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=180,
  serialized_end=320,
)

_DOUBLEMATCHER.fields_by_name['range'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._DOUBLERANGE
_DOUBLEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _DOUBLEMATCHER.fields_by_name['range'])
_DOUBLEMATCHER.fields_by_name['range'].containing_oneof = _DOUBLEMATCHER.oneofs_by_name['match_pattern']
_DOUBLEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _DOUBLEMATCHER.fields_by_name['exact'])
_DOUBLEMATCHER.fields_by_name['exact'].containing_oneof = _DOUBLEMATCHER.oneofs_by_name['match_pattern']
DESCRIPTOR.message_types_by_name['DoubleMatcher'] = _DOUBLEMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DoubleMatcher = _reflection.GeneratedProtocolMessageType('DoubleMatcher', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEMATCHER,
  '__module__' : 'envoy.type.matcher.v3.number_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v3.DoubleMatcher)
  })
_sym_db.RegisterMessage(DoubleMatcher)


DESCRIPTOR._options = None
_DOUBLEMATCHER.oneofs_by_name['match_pattern']._options = None
_DOUBLEMATCHER._options = None
# @@protoc_insertion_point(module_scope)
